# Copyright (C) 2024 Manuel Bustillo

Rails.application.routes.draw do
  mount LetterOpenerWeb::Engine, at: "/letter_opener" if Rails.env.development?
  devise_for :users, skip: [:registration, :session, :confirmation]
  devise_scope :user do
    post 'users', to: 'users/registrations#create'

    post '/users/sign_in', to: 'users/sessions#create'
    delete '/users/sign_out', to: 'users/sessions#destroy'

    get '/users/confirmation', to: 'users/confirmations#show', as: :confirmation
  end

  mount Rswag::Ui::Engine => '/api-docs'
  mount Rswag::Api::Engine => '/api-docs'
  resources :groups, only: :index
  resources :guests, only: %i[index create update destroy] do
    post :bulk_update, on: :collection
  end
  resources :expenses, only: %i[index update] do
    get :summary, on: :collection
  end
  resources :tables_arrangements, only: %i[index show]

  get 'up' => 'rails/health#show', as: :rails_health_check

  root to: redirect('/dashboard')
end
